# gknames
A transient nameserver + API aimed at ATLAS and Pan-STARRS transients. By default the
server runs under mod_wsgi-express and the webserver on the host machine should be setup to
proxy to the designated mod_wsgi-express port.
